% LIQDMENU liquid plot control menu
%         LIQDMENU defines the control menu to plot the liquid configuration.
%         Automatic adjustment to Matlab version 4 or 5. 
%         Options:
%           Check how many data files are available
%           Select the number of the data file to be plotted
%           Select variable to be plotted
%           Select between color and contour plots
%           Manually override colorrange
%           Manually override vector scaling
%           Edit the title of the plot
%           Animate a user-specified selection of these data as a movie
%           Export movie as mat-file, mpg-file or set of jpg-files
%           Plot variables along cross-sections
%           Start-up streamline display (still under command-window control)
%           Display the geometry 
%           Plot streamfunction and vorticity (if available)
%           Export any plots as a user-named printfile (*.epsc or *.jpg)


%           Filename: liqdmenu.m
%           Date    : 27 March 1999
%           Author  : A.E.P. Veldman

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Calling sequence:
%
%      m-file                input files      output files
%
% liqdmenu.m                 uvpf####.dat
%    |
%    |-- liqdplot.m          config.dat       *.mpg
%    |                       uvpf####.dat     *.mat
%    |                       (humi####.dat)
%    |                                        *.jpg
%    |     
%    |-- xplot.m             config.dat
%    |                       uvpf####.dat
%    |                       (humi####.dat)
%    |
%    |-- liqprint.m                           *.eps
%    |                                        *.jpg 
%    |
%    |-- strmplot.m          stream.out       traces.mat
%    |      |                (traces.mat)
%    |      |-- geoplot.m    config.dat
%    |
%    |-- geoplot.m           config.dat
%    |
%    |-- psiomega.m          config.dat
%                            psiomega.dat
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Changes
% March 2001: (MTD)
%     -Multiple plot figures support;
%     -Velocity vectors switched on/off separately;
%     -Relative or absolute scaling of velocity vectors;
%     -A probe button is added;
%     -Hor./vert. velocity added for surface/contour plots;
%     -Absolute velocity added for X/Y-plot;
%     -AVI support added for Matlab6;
%     -Matlab6 bug fixed: getframe and movie grab/display in whole
%                         figure instead of axes;
%     -Directory-frame added at bottom of menu;
%     -Right clicking on '??' counts only new data files;
%     -Right clicking on '<' selects plot 1;
%     -Right clicking on '>' selects last new plot;
%     -'LIVE' button added for live animations (interruptible!);
%     -Variables can be set to omit parts of the menu;
%     -humidity data added to uvpf####.dat instead of humi####.dat;
%     -A 'keepzoom' button for fixing the focus between successive plots;
%
% To-do list
%     -Read gzip-ed data files;
%     -Mirroring in both directions;
%     -Adding contourplots to surface plots;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

clear all
clf

% GLOBAL variables

global lq_snap lq_prt lq_mpg lq_quiver lq_relscale lq_absscale lq_cmode
global lq_cmin lq_cmax lq_live lq_sel lq_zoom
global lq_xmode lq_xmin lq_xmax lq_xhold lq_stride lq_bar lq_cntr lq_clbl
global lq_1axismin lq_1axismax lq_2axismin lq_2axismax lq_keepaspect
global plotfg optsclr optsstl optsmrk optswdt optsmrksz
global menuclr menustl menumrk menuwdt menumrksz
global clrlst stllst mrklst wdtlst mrkszlst
global clrstr stlstr mrkstr wdtstr mrkszstr
global x y data M tel tekst oudval

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% The following default settings can be customized by user
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% setting frames on (1) or off (0)
zoomframe=1;
XYframe=1;
printframe=1;
movieframe=1;
closeframe=1;
partgeopsiomeframe=0;
directoryframe=0;

% display 'live' button?
livebutton=0;

% menu bar?
menubar=0;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% read info in .liqdmenu
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
eval('[dummy,prefix]=unix(''echo $HOME'');', 'prefix=''./'';');
prefix=prefix(1:length(prefix)-1); % removal of new-line

eval([ ...
  'if isunix,', ...
  'load ', prefix,'/.liqdmenu.mat;', ...
  'end'], '0;');

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% save settings in .liqdmenu
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
savesettings=[ 'eval(''', ...
  'if isunix,', ...
    'save ', prefix,'/.liqdmenu.mat zoomframe XYframe printframe ', ...
         'movieframe closeframe partgeopsiomeframe directoryframe ', ...
	 'livebutton;', ...
  'end;', ...
  ''', ''0;'');'];


% define frame heights
frameheight=zeros(1,9);
frameheight(1)=205;                    % color plot
frameheight(2)= 35*zoomframe;          % zoom
frameheight(3)= 35;                    % title/plot button
frameheight(4)=123*XYframe;            % X/Y-sectons
frameheight(5)= 53*printframe;         % print
frameheight(6)= 88*movieframe;         % movie
frameheight(7)= 43*closeframe;         % close button
frameheight(8)=131*partgeopsiomeframe; % part. path, geo., psi-omega
frameheight(9)= 40*directoryframe;     % directory frame

% if close button is last frame, add black frame
if (sum(frameheight(8:9))==0 & closeframe), frameheight(8)=8; end;

% define main control window; make sure it is not in window 1
lqfig=figure(1);
clf reset
set(lqfig, ...
    'NumberTitle', 'off', ...
    'MenuBar', 'none', ...
    'Name', 'Liquid Plot Control Menu', ...
    'Position', [10 150 400 sum(frameheight)], ...
    'Units', 'normal', ...
    'Resize','off');

% define plot window
plotfg=figure(2);

% define colors
bordercolor=[0.25 0.25 0.25];
buttoncolor=[0.775 0.775 0.775];
editcolor=[0.95 0.95 0.95];
errorcolor=[1.0 0.5 0.5];


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% menu
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if (menubar),

filemenu = uimenu(lqfig, 'Label', '&File');
  fileexitmenu=uimenu(filemenu, 'Label', 'E&xit');
optionsmenu = uimenu(lqfig, 'Label', '&Options');
  optionsframemenu=uimenu(optionsmenu, 'Label', '&Frame');
    zoomoptionsframemenu=uimenu(optionsframemenu, 'Label', '&Zoom');
    XYoptionsframemenu=uimenu(optionsframemenu, 'Label', '&XY-sections');
    printoptionsframemenu=uimenu(optionsframemenu, 'Label', '&Print');
    movieoptionsframemenu=uimenu(optionsframemenu, 'Label', '&Movie');
    closeoptionsframemenu=uimenu(optionsframemenu, 'Label', '&Close');
    pgpoptionsframemenu=uimenu(optionsframemenu, ...
			       'Label', 'Part.paths/&Geometry/Psi-Omega');
    diroptionsframemenu=uimenu(optionsframemenu, 'Label', '&Directory');
  optionslivemenu=uimenu(optionsmenu, 'Label', '&Live button');
% initial check
  if zoomframe set(zoomoptionsframemenu, 'Checked', 'on'); end;
  if XYframe set(XYoptionsframemenu, 'Checked', 'on'); end;
  if printframe set(printoptionsframemenu, 'Checked', 'on'); end;
  if movieframe set(movieoptionsframemenu, 'Checked', 'on'); end;
  if closeframe set(closeoptionsframemenu, 'Checked', 'on'); end;
  if partgeopsiomeframe set(pgpoptionsframemenu, 'Checked', 'on'); end;
  if directoryframe set(diroptionsframemenu, 'Checked', 'on'); end;
  if livebutton set(optionslivemenu, 'Checked', 'on'); end;
% menu actions
set(fileexitmenu, 'CallBack', 'close(lqfig)');
set(optionslivemenu, 'CallBack', [ ...
    'if strcmp(get(optionslivemenu, ''Checked''), ''on''),', ...
      'livebutton=0;', savesettings, 'ls,', ...
      'figure(lqfig);close;liqdmenu;', ...
    'else,', ...
      'livebutton=1;', savesettings, 'ls,', ...
      'figure(lqfig);close;liqdmenu;', ...
    'end;']);
set(zoomoptionsframemenu, 'CallBack', [ ...
    'if strcmp(get(zoomoptionsframemenu, ''Checked''), ''on''),', ...
      'zoomframe=0;', savesettings, ...
      'figure(lqfig);close;liqdmenu;', ...
    'else,', ...
      'zoomframe=1;', savesettings, ...
      'figure(lqfig);close;liqdmenu;', ...
    'end;']);
set(XYoptionsframemenu, 'CallBack', [ ...
    'if strcmp(get(XYoptionsframemenu, ''Checked''), ''on''),', ...
      'XYframe=0;', savesettings, ...
      'figure(lqfig);close;liqdmenu;', ...
    'else,', ...
      'XYframe=1;', savesettings, ...
      'figure(lqfig);close;liqdmenu;', ...
    'end;']);
set(printoptionsframemenu, 'CallBack', [ ...
    'if strcmp(get(printoptionsframemenu, ''Checked''), ''on''),', ...
      'printframe=0;', savesettings, ...
      'figure(lqfig);close;liqdmenu;', ...
    'else,', ...
      'printframe=1;', savesettings, ...
      'figure(lqfig);close;liqdmenu;', ...
    'end;']);
set(movieoptionsframemenu, 'CallBack', [ ...
    'if strcmp(get(movieoptionsframemenu, ''Checked''), ''on''),', ...
      'movieframe=0;', savesettings, ...
      'figure(lqfig);close;liqdmenu;', ...
    'else,', ...
      'movieframe=1;', savesettings, ...
      'figure(lqfig);close;liqdmenu;', ...
    'end;']);
set(closeoptionsframemenu, 'CallBack', [ ...
    'if strcmp(get(closeoptionsframemenu, ''Checked''), ''on''),', ...
      'closeframe=0;', savesettings, ...
      'figure(lqfig);close;liqdmenu;', ...
    'else,', ...
      'closeframe=1;', savesettings, ...
      'figure(lqfig);close;liqdmenu;', ...
    'end;']);
set(pgpoptionsframemenu, 'CallBack', [ ...
    'if strcmp(get(pgpoptionsframemenu, ''Checked''), ''on''),', ...
      'partgeopsiomeframe=0;', savesettings, ...
      'figure(lqfig);close;liqdmenu;', ...
    'else,', ...
      'partgeopsiomeframe=1;', savesettings, ...
      'figure(lqfig);close;liqdmenu;', ...
    'end;']);
set(diroptionsframemenu, 'CallBack', [ ...
    'if strcmp(get(diroptionsframemenu, ''Checked''), ''on''),', ...
      'directoryframe=0;', savesettings, ...
      'figure(lqfig);close;liqdmenu;', ...
    'else,', ...
      'directoryframe=1;', savesettings, ...
      'figure(lqfig);close;liqdmenu;', ...
    'end;']);
end;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% frame 1 (snapshot, title, plot)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
lower=sum(frameheight(2:9));

% function for setting the available figures in lq_fig, and set
% plotfg to the selected figure.
setfigs=([ ...
    'figs=sort(get(0,''Children'')'');', ...
    'strfigs=[''new '', sprintf('' | %i '', figs(2:length(figs)))];', ...
    'figs(1)=figs(length(figs))+1;', ...
    'if get(lq_fig, ''Value'')>length(figs)+1,', ...
       'set(lq_fig, ''Value'', 1);', ...
    'end;' ...
    'set(lq_fig, ''String'', strfigs);', ...
    'plotfg=figs(get(lq_fig, ''Value''));' ] );

% frame containing selection of snapshot and variable
uicontrol(lqfig,'Style','frame', ...
	     'Position',[0 lower-sum(frameheight(2:3)) ...
			 400 sum(frameheight(1:3))]);

% diaplay some text
uicontrol(lqfig,'Style','text', ...
             'Position',[15 lower+180 110 15], ...
             'Horizontal','left', ... 
             'String','COLOR PLOT');
uicontrol(lqfig,'Style','text', ...
             'Position',[330 lower+180 60 15], ...
             'Foreground',[1 1 1], ...
             'String','060301');

% live presentation
if (livebutton),
args=['str2num(get(lq_sel,''String'')), 9999, ' ...
      'get(lq_col,''Value''), -1'];
lq_live=uicontrol(lqfig,'Style','push', ...
	     'Position',[150 lower+175 100 25], ...
             'String', 'LIVE', ...
	     'Background', [1.0 0.5 0.0], ...
	     'Foreground', [1 1 1], ...
             'CallBack',[ ...
		 'if strcmp(get(lq_live, ''String''), ''LIVE''),', ...
                   'if (closeframe),', ...
		     'set(lq_close, ''Visible'', ''off'');', ...
	 	     'set(lq_close_livetxt, ''Visible'', ''on'');', ...
		   'else,', ...
		     'disp(''In live mode. ', ...
		          'Wait or click STOP to interrupt ...'');', ...
		   'end;', ...
		   'set(lq_live, ''String'', ''STOP'');', ...
		   'figure(plotfg),', ...
		   'liqdplot(' args ');', ...
		   setfigs, ...
		   'set(lq_live, ''String'', ''LIVE'');', ...
                   'if (closeframe),', ...
      	             'set(lq_close_livetxt, ''Visible'', ''off'');', ...
  		     'set(lq_close, ''Visible'', ''on'');', ...
		   'end;', ...
		 'else,', ...
		   'set(lq_live, ''String'', ''LIVE'');', ...
                   'if (closeframe),', ...
      	             'set(lq_close_livetxt, ''Visible'', ''off'');', ...
  		     'set(lq_close, ''Visible'', ''on'');', ...
		   'end;', ...
		 'end']);
end;
	     
% selection of plot figure
lq_figtxt=uicontrol(lqfig,'Style','text', ...
             'Position',[15 lower+118 100 15], ... 
             'Horizontal','left', ...
             'String',[ 'plot figure:']);
lq_fig=uicontrol(lqfig, 'Style', 'popup', ...
             'Position', [80 lower+113 60 25], ...
             'Background',buttoncolor, ...
             'HorizontalAlignment','right', ...
	     'String', [ ' dum1 | dum2 ' ], ...
             'Value', 2, ...
	     'CallBack', [ 'plotfg=figs(get(lq_fig, ''Value''));' ] );

% set contents of lq_fig
eval(setfigs);
set(lq_fig, 'Value', 2);
eval(setfigs);

% count the number of available data files for liquid configuration
countfiles=([ ...
  'fid=1; i=1; ', ...
  'while fid~=-1,', ...
    'name=int2str(i);', ...
    'while length(name)<4, name=[''0'',name]; end,', ...
    'fid=fopen([''uvpf'',name,''.dat'']);', ...
    'if fid~=-1, fclose(fid); end,', ...
    'i=i+1;', ...
  'end,', ...
  'npt=i-2;', ...
  'set(lq_many,''String'',num2str(npt));', ...
  'if (movieframe), set(lq_to,''String'',num2str(npt)); end;' ]);

% count the number of new data files for liquid configuration
countnewfiles=([ ...
  'prevtime=0; next=1; result=0;' ...
  'while (next),' ...
    'name=[''uvpf'',sprintf(''%04d'', result+1),''.dat''];' ...
    'file=dir(name);' ...
    'if (~isempty(file)),' ...
      'if ( datenum(file.date) >= prevtime),' ...
        'result=result+1;' ...
        'prevtime=datenum(file.date);' ...
      'else,' ...
        'next=0;' ...
      'end;' ...
    'else,' ...
      'next=0;' ...
    'end;' ...
  'end;' ...
  'set(lq_many,''String'',num2str(result));' ...
  'if (movieframe), set(lq_to,''String'',num2str(result)); end;' ...
]);

% display number of available data files
lq_many=uicontrol(lqfig,'Style','push', ...
             'Position',[15 lower+145 40 25], ...
             'String','??', ...
             'Horizontal','center', ...
             'Background',[0.7 0.7 0.7], ...
             'CallBack', countfiles, ...
             'ButtonDownFcn', countnewfiles);
lq_snap=uicontrol(lqfig,'Style','text', ...
             'Position',[60 lower+150 200 15], ...
             'Horizontal','left', ...
             'String',[ 'snapshots available']);

% select plot number
uicontrol(lqfig,'Style','text', ...
             'Position',[210 lower+150 80 15], ... 
             'String',['select #:'], ...
             'Horizontal','right');
lq_sel=uicontrol(lqfig,'Style','edit', ...
             'Position',[315 lower+147 50 21], ...
             'Horizontal','left', ...
             'Background',editcolor, ...
	     'String','1');

% buttons for changing plot number
aktiemin=['a=str2num(get(lq_sel,''String''));,a=max(a-1,1);,', ...
             'set(lq_sel,''String'',num2str(a))'];
uicontrol(lqfig,'Style','push', ...
             'Position',[295 lower+150 15 15], ...
             'String',['<'], ...
             'Background',buttoncolor, ...
             'CallBack',aktiemin, ...
	     'ButtonDownFcn', 'set(lq_sel, ''String'', ''1'')');

aktieplus=['a=str2num(get(lq_sel,''String''));,a=a+1;,', ...
	     'set(lq_sel,''String'',num2str(a))'];
uicontrol(lqfig,'Style','push', ...
             'Position',[370 lower+150 15 15], ...
             'String',['>'], ...
             'Background',buttoncolor, ...
             'CallBack',aktieplus, ...
	     'ButtonDownFcn', [countnewfiles, ...
	         'set(lq_sel, ''String'', get(lq_many, ''String''))']);

% variable to be plotted
uicontrol(lqfig,'Style','text', ...
             'Position',[140 lower+118 60 15], ... 
             'String','variable:', ...
             'Horizontal','right');
lq_col=uicontrol(lqfig,'Style','popup', ...
             'Position',[210 lower+113 180 25], ...
             'Background',buttoncolor, ...
	     'String', [' absolute velocity ' ...
		 '| horizontal velocity | vertical velocity ' ...
		 '| pressure | vorticity | streamfunction '], ...
             'Value',1, ... 
             'CallBack', [...
                 'set(lq_cmode,''Enable'',''on''),' ...
		 'set(lq_probe,''Visible'',''on''),' ...
		 'set(lq_quiver,''Value'',1),' ...
		 'set(lq_absscale,''Visible'',''off''),' ...
		 'set(lq_relscale,''Visible'',''off''),' ...
		 'set(lq_scaletxt,''Visible'',''off''),' ...
		 'set(lq_zero,''Visible'',''off''),' ...
		 'set(lq_reset,''Visible'',''off''),' ...
		 'set(lq_stride,''Visible'',''off''),' ...
		 'set(lq_stridetxt,''Visible'',''off''),' ...
		 'set(lq_cmode,''Value'',0),' ...' 
		 'set(lq_cmintxt,''Visible'',''off''),' ...
		 'set(lq_cmin,''Visible'',''off''),' ...
		 'set(lq_cmaxtxt,''Visible'',''off''),' ...
		 'set(lq_cmax,''Visible'',''off'') ' ]);


% colormap control

uicontrol(lqfig,'Style','frame', ...
	     'Position',[0 lower 205 105]);

% surface or contour plots?
lq_cntr=uicontrol(lqfig,'Style','popup', ...
             'Position',[10 lower+73 85 25], ...
             'String',['surface | contour'], ...
             'Value',1, ...
             'Background',buttoncolor, ...
             'Horizontal','center', ...
             'CallBack', [...
                 'if (get(lq_cntr,''Value'') == 2),' ...
                   'set(lq_clbl,''Visible'',''on''),' ...
                   'set(lq_bar,''Visible'',''off''),' ...
                 'else,' ...
                   'set(lq_clbl,''Visible'',''off''),' ...
		   'set(lq_bar,''Visible'',''on''),' ...
		 'end' ]);

% colorbar?
lq_bar=uicontrol(lqfig,'Style','checkbox', ...
             'Position',[115 lower+73 80 25], ...
             'String',['colorbar'], ...
             'Value',1, ...
             'Background',buttoncolor, ...
             'Horizontal','left', ...
             'Visible','on');
% clabels?
lq_clbl=uicontrol(lqfig,'Style','checkbox', ...
             'Position',[115 lower+73 80 25], ...
             'String',['clabel'], ...
             'Value',0, ...
             'Background',buttoncolor, ...
             'Horizontal','left', ...
             'Visible','off');


% colormap manual definition 
lq_cmode=uicontrol(lqfig,'Style','checkbox', ...
             'Position',[40 lower+38 120 25], ...
             'Background',buttoncolor, ...
             'Enable','on', ...
             'String', ['caxis manual'], 'Value',0, ...
             'CallBack', [...
                 'if (get(lq_cmode,''Value'') == 1),' ...
                   'set(lq_cmintxt,''Visible'',''on''),' ...
		   'set(lq_cmin,''Visible'',''on''),' ...
 		   'set(lq_cmaxtxt,''Visible'',''on''),' ...
                   'set(lq_cmax,''Visible'',''on''),' ...
                 'else,' ...
                   'set(lq_cmintxt,''Visible'',''off''),' ...
                   'set(lq_cmin,''Visible'',''off''),' ...
                   'set(lq_cmaxtxt,''Visible'',''off''),' ...
                   'set(lq_cmax,''Visible'',''off''),' ...
                 'end' ]);
lq_cmintxt=uicontrol(lqfig,'Style','text', ...
             'Position',[15 lower+10 30 15], ...
             'String','min:', ...
             'Visible','off', ...
             'Horizontal','left');
lq_cmin=uicontrol(lqfig,'Style','edit', ...
             'String','0', ...
             'Position',[47,lower+7,45,21], ...
             'Visible','off', ...
             'Background',editcolor, ...
             'Horizontal','left');
lq_cmaxtxt=uicontrol(lqfig,'Style','text', ...
             'Position',[105 lower+10 30 15], ...
             'String','max:', ...
             'Visible','off', ...
             'Horizontal','left');
lq_cmax=uicontrol(lqfig,'Style','edit', ...
             'String','1', ...
             'Position',[137,lower+7,45,21], ...
             'Visible','off', ...
             'Background',editcolor, ...
             'Horizontal','left');

% frame with velocity vectors control and probe
uicontrol(lqfig,'Style','frame', ...
	     'Position',[205 lower 195 105]);

% probe button
lq_probe=uicontrol(lqfig, 'Style', 'push', ...
             'Position',[235 lower+37 135 25], ...
             'String', 'probe', ...
             'Background',buttoncolor, ...
	     'Visible','on', ...
	     'CallBack', [...
		 'if (closeframe),', ...
		   'set(lq_close, ''Visible'', ''off'');', ...
		   'set(lq_close_probetxt, ''Visible'', ''on'');', ...
		 'else,', ...
		   'disp(''Click somewhere in the ', ...
		         'graphic window ...'');', ...
		 'end;', ...
		 'if(isempty(get(figure(plotfg),''CurrentAxes''))),', ...
		   'xginp=NaN; yginp=NaN;', ...
		   'disp(''Invalid plot figure selected.'');', ...
		 'else,', ...
		   '[xginp, yginp]=ginput(1);', ...
		 'end;', ...
		 'iginp=-1; jginp=-1;', ...
		 'eval(''lenx=length(x);'', ''lenx=0;'');',...
		 'for i=1:lenx-1;', ...
		   'if (x(i)<=xginp & xginp<x(i+1)) iginp=i; end;', ...
		 'end;', ...
		 'eval(''leny=length(y);'', ''leny=0;'');',...
		 'for j=1:leny-1;', ...
  		   'if (y(j)<=yginp & yginp<y(j+1)) jginp=j; end;', ...
		 'end;', ...
		 'if (iginp>0 & jginp > 0),', ...
		   'sprintf(''X=%0.5g, Y=%0.5g\n', ...
		   'I=%i, J=%i\nValue=%0.5g'', xginp, yginp,', ...
		   'iginp, jginp, data(iginp,jginp)),', ...
		 'else,', ...
		   'disp(''No plot data available. Replot first.'');', ...
		 'end;', ...
		 'if (closeframe),', ...
                   'set(lq_close_probetxt, ''Visible'', ''off'');', ...
		   'set(lq_close, ''Visible'', ''on'');', ...
		 'end'] );

% velocity vectors control
lq_quiver=uicontrol(lqfig,'Style','popup', ...
             'Position',[235 lower+73 135 25], ...
             'Background',buttoncolor, ...
             'String', [' no velocity vectors | arrows automatic ' ...
		        '| relative scaling | absolute scaling'], ...
             'Value',1, ...
             'CallBack', [...
                 'if (get(lq_quiver,''Value'') == 3),' ...
                   'set(lq_absscale,''Visible'',''off''),' ...
		   'set(lq_relscale,''Visible'',''on''),' ...
		   'set(lq_scaletxt,''Visible'',''on''),' ...
                   'set(lq_zero,''Visible'',''on''),' ...
                   'set(lq_reset,''Visible'',''on''),'...
                   'set(lq_stride,''Visible'',''on''),'...
                   'set(lq_stridetxt,''Visible'',''on''),' ...
                 'elseif (get(lq_quiver,''Value'') == 4),' ...
                   'set(lq_absscale,''Visible'',''on''),' ...
                   'set(lq_scaletxt,''Visible'',''on''),' ...
                   'set(lq_stride,''Visible'',''on''),'...
                   'set(lq_stridetxt,''Visible'',''on''),' ...
 		   'set(lq_relscale,''Visible'',''off''),' ...
                   'set(lq_zero,''Visible'',''off''),' ...
                   'set(lq_reset,''Visible'',''off''),' ...
		 'else,', ...
 		   'set(lq_relscale,''Visible'',''off''),' ...
 		   'set(lq_absscale,''Visible'',''off''),' ...
                   'set(lq_scaletxt,''Visible'',''off''),' ...
                   'set(lq_zero,''Visible'',''off''),' ...
                   'set(lq_reset,''Visible'',''off''),' ...
                   'set(lq_stride,''Visible'',''off''),' ...
                   'set(lq_stridetxt,''Visible'',''off''),' ...
                 'end;' ...
		  'if (get(lq_quiver,''Value'') == 1),' ...
 		    'set(lq_probe,''Visible'',''on''),' ...
		  'else,' ...
 		    'set(lq_probe,''Visible'',''off''),' ...
		  'end' ]);
lq_scaletxt=uicontrol(lqfig,'Style','text', ...
             'Position',[215 lower+40 100 15], ...
             'String','scale:', ...
             'Visible','off', ...
	     'Horizontal','center');
lq_zero=uicontrol(lqfig,'Style','text', ...
             'Position',[260 lower+28 10 10], ...
	     'Visible','off', ...
             'String','!');
lq_relscale=uicontrol(lqfig,'Style','slider', ...
             'Position',[215 lower+14 100 19], ...
             'Background',buttoncolor, ...
	     'Visible','off', ...
             'Min',-5,'Max',5,'Value',0);
lq_absscale=uicontrol(lqfig,'Style','edit', ...
             'Position',[245 lower+14 60 20], ...
	     'String', '1', ...
             'Background', editcolor, ...
	     'Visible','off', ...
             'Horizontal','left');
lq_reset=uicontrol(lqfig,'Style','push', ...
             'Position',[323 lower+17 10 10], ...
             'String',[' '], ...
             'Background',buttoncolor, ...
	     'Visible','off', ...
	     'CallBack', 'set(lq_relscale,''Value'',0),');
lq_stridetxt=uicontrol(lqfig,'Style','text', ...
             'Position',[350 lower+40 40 15], ...
             'String','stride:', ...
             'Visible','off', ...
             'Horizontal','center');
lq_stride=uicontrol(lqfig,'Style','popup', ...
             'Position',[350 lower+14 40 21], ...
             'String',['1 |2 |3 |4 '], ...
             'Background',buttoncolor, ...
             'Value',1, ...
             'Visible','off');             

if (zoomframe),
lower=sum(frameheight(3:9));
uicontrol(lqfig,'Style','frame', ...
	     'Position',[0 lower 400 2]);
lq_zoom=uicontrol(lqfig,'Style','popup', ...
             'Position',[10 lower+6 130 25], ...
             'Background',buttoncolor, ...
             'String', [' automatic zoom | manual x-axis |', ...
                        ' manual y-axis | manual x-y-axes |', ...
		        ' keep last zoom '], ... 
             'Value',1, ...
	     'CallBack', [ ...
		 'if (get(lq_zoom, ''Value'')==1),', ...
		   'set(lq_keepaspect, ''Visible'', ''on'');', ...
		   'set(lq_keepaspect, ''Enable'', ''on'');', ...
		   'set(lq_1axismintxt, ''Visible'', ''off'');', ...
		   'set(lq_1axismaxtxt, ''Visible'', ''off'');', ...
		   'set(lq_2axismintxt, ''Visible'', ''off'');', ...
		   'set(lq_2axismaxtxt, ''Visible'', ''off'');', ...
		   'set(lq_1axismin, ''Visible'', ''off'');', ...
		   'set(lq_1axismax, ''Visible'', ''off'');', ...
		   'set(lq_2axismin, ''Visible'', ''off'');', ...
		   'set(lq_2axismax, ''Visible'', ''off'');', ...
		 'elseif (get(lq_zoom, ''Value'')==2),', ...
		   'set(lq_keepaspect, ''Visible'', ''on'');', ...
		   'set(lq_keepaspect, ''Enable'', ''on'');', ...
		   'set(lq_1axismintxt, ''Visible'', ''on'');', ...
		   'set(lq_1axismaxtxt, ''Visible'', ''on'');', ...
		   'set(lq_2axismintxt, ''Visible'', ''off'');', ...
		   'set(lq_2axismaxtxt, ''Visible'', ''off'');', ...
		   'set(lq_1axismin, ''Visible'', ''on'');', ...
		   'set(lq_1axismax, ''Visible'', ''on'');', ...
		   'set(lq_2axismin, ''Visible'', ''off'');', ...
		   'set(lq_2axismax, ''Visible'', ''off'');', ...
		   'set(lq_1axismintxt, ''String'', ''x:'');', ...
		 'elseif (get(lq_zoom, ''Value'')==3),', ...
		   'set(lq_keepaspect, ''Visible'', ''on'');', ...
		   'set(lq_keepaspect, ''Enable'', ''on'');', ...
		   'set(lq_1axismintxt, ''Visible'', ''on'');', ...
		   'set(lq_1axismaxtxt, ''Visible'', ''on'');', ...
		   'set(lq_2axismintxt, ''Visible'', ''off'');', ...
		   'set(lq_2axismaxtxt, ''Visible'', ''off'');', ...
		   'set(lq_1axismin, ''Visible'', ''on'');', ...
		   'set(lq_1axismax, ''Visible'', ''on'');', ...
		   'set(lq_2axismin, ''Visible'', ''off'');', ...
		   'set(lq_2axismax, ''Visible'', ''off'');', ...
		   'set(lq_1axismintxt, ''String'', ''y:'');', ...
		 'elseif (get(lq_zoom, ''Value'')==4),', ...
		   'set(lq_keepaspect, ''Visible'', ''off'');', ...
		   'set(lq_keepaspect, ''Enable'', ''on'');', ...
		   'set(lq_1axismintxt, ''Visible'', ''on'');', ...
		   'set(lq_1axismaxtxt, ''Visible'', ''on'');', ...
		   'set(lq_2axismintxt, ''Visible'', ''on'');', ...
		   'set(lq_2axismaxtxt, ''Visible'', ''on'');', ...
		   'set(lq_1axismin, ''Visible'', ''on'');', ...
		   'set(lq_1axismax, ''Visible'', ''on'');', ...
		   'set(lq_2axismin, ''Visible'', ''on'');', ...
		   'set(lq_2axismax, ''Visible'', ''on'');', ...
		   'set(lq_1axismintxt, ''String'', ''x:'');', ...
		 'else,', ...
		   'set(lq_keepaspect, ''Visible'', ''on'');', ...
		   'set(lq_keepaspect, ''Enable'', ''off'');', ...
		   'set(lq_1axismintxt, ''Visible'', ''off'');', ...
		   'set(lq_1axismaxtxt, ''Visible'', ''off'');', ...
		   'set(lq_2axismintxt, ''Visible'', ''off'');', ...
		   'set(lq_2axismaxtxt, ''Visible'', ''off'');', ...
		   'set(lq_1axismin, ''Visible'', ''off'');', ...
		   'set(lq_1axismax, ''Visible'', ''off'');', ...
		   'set(lq_2axismin, ''Visible'', ''off'');', ...
		   'set(lq_2axismax, ''Visible'', ''off'');', ...
		 'end;']);
lq_1axismintxt=uicontrol(lqfig,'Style','text', ...
             'Position',[145 lower+9 20 15], ...
             'String','x:', ...
             'Visible','off', ...
             'Horizontal','left');
lq_1axismaxtxt=uicontrol(lqfig,'Style','text', ...
             'Position',[207 lower+9 10 15], ...
             'String','-', ...
             'Visible','off', ...
             'Horizontal','left');
lq_2axismintxt=uicontrol(lqfig,'Style','text', ...
             'Position',[270 lower+9 20 15], ...
             'String','y:', ...
             'Visible','off', ...
             'Horizontal','left');
lq_2axismaxtxt=uicontrol(lqfig,'Style','text', ...
             'Position',[332 lower+9 10 15], ...
             'String','-', ...
             'Visible','off', ...
             'Visible','off', ...
             'Horizontal','left');
lq_1axismin=uicontrol(lqfig,'Style','edit', ...
             'String','0', ...
             'Position',[165,lower+7,40,21], ...
             'Background',editcolor, ...
             'Visible','off', ...
             'Horizontal','left');
lq_1axismax=uicontrol(lqfig,'Style','edit', ...
             'String','1', ...
             'Position',[218,lower+7,40,21], ...
             'Background',editcolor, ...
             'Visible','off', ...
             'Horizontal','left');
lq_2axismin=uicontrol(lqfig,'Style','edit', ...
             'String','0', ...
             'Position',[290,lower+7,40,21], ...
             'Background',editcolor, ...
             'Visible','off', ...
             'Horizontal','left');
lq_2axismax=uicontrol(lqfig,'Style','edit', ...
             'String','1', ...
             'Position',[343,lower+7,40,21], ...
             'Background',editcolor, ...
             'Visible','off', ...
             'Horizontal','left');

lq_keepaspect=uicontrol(lqfig,'Style','checkbox', ...
             'Position',[290,lower+6,100,25], ...
  	     'Value', 1, ...
             'String','1:1 aspect', ...
             'Background',buttoncolor);
end;

% edit title
lower=sum(frameheight(4:9));

lq_add=uicontrol(lqfig,'Style','push', ...
             'Position',[10,lower+5,100,25], ...
             'String','add title', ...
             'Background',buttoncolor, ...
             'CallBack', [...
                 'set(lq_edittxt,''Visible'',''on''),' ...
		 'set(lq_edit,''Visible'',''on''),' ...
		 'set(lq_addok,''Visible'',''on''),' ...
		 'set(lq_addcncl,''Visible'',''on''),' ...
		 'set(lq_add,''Visible'',''off''),' ...
		 'set(lq_plot,''Visible'',''off'')' ] );
lq_edittxt=uicontrol(lqfig,'Style','text', ...
             'Position',[15 lower+10 35 15], ...
             'String','title:', ...
             'Visible','off', ...
             'Horizontal','left');
lq_edit=uicontrol(lqfig,'Style','edit', ...
             'String','voorbeeld titel', ...
             'Position',[60,lower+7,190,21], ...
             'Visible','off', ...
             'Background',editcolor, ...
             'Horizontal','left');
lq_addok=uicontrol(lqfig,'Style','push', ...
             'Position',[290,lower+5,50,25], ...
             'String','OK', ...
             'Visible','off', ...
             'Background',buttoncolor, ...
             'CallBack', [...
                 'figure(plotfg),' ...
                 'title(get(lq_edit,''String''),''Fontsize'',16), ' ...
                 'set(lq_edittxt,''Visible'',''off''),' ...
                 'set(lq_edit,''Visible'',''off''),' ...
                 'set(lq_addok,''Visible'',''off''),' ...
                 'set(lq_addcncl,''Visible'',''off''),' ...
                 'set(lq_add,''Visible'',''on''),' ...
                 'set(lq_plot,''Visible'',''on'')' ] );
lq_addcncl=uicontrol(lqfig,'Style','push', ...
             'Position',[340,lower+5,50,25], ...
             'String','cancel', ...
             'Visible','off', ...
             'Background',buttoncolor, ...
             'CallBack', [...
                 'set(lq_edittxt,''Visible'',''off''),' ...
                 'set(lq_edit,''Visible'',''off''),' ...
                 'set(lq_addok,''Visible'',''off''),' ...
                 'set(lq_addcncl,''Visible'',''off''),' ...
                 'set(lq_add,''Visible'',''on''),' ...
                 'set(lq_plot,''Visible'',''on'')' ] );

% plot command
args=['str2num(get(lq_sel,''String'')),' ...
      'str2num(get(lq_sel,''String'')),' ...
      'get(lq_col,''Value'')+1, 0'];
lq_plot=uicontrol(lqfig,'Style','push', ...
             'Position',[210 lower+5 180 25], ...
             'String','PLOT', ...
             'Background',buttoncolor, ...
             'CallBack',[' figure(plotfg), liqdplot(' args ');', setfigs]  );


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% frame 2 (X/Y-sections)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
lower=sum(frameheight(5:9));

if (XYframe),

% frames/text
uicontrol(lqfig,'Style','frame', ...
	     'Position',[0 lower+115 400 8], ...
             'Background', bordercolor );
uicontrol(lqfig,'Style','frame', ...
	     'Position',[0 lower 400 115]);

uicontrol(lqfig,'Style','text', ...
             'Position',[15 lower+85 150 15], ...
             'Horizontal','left', ...
             'String','X/Y-SECTIONS');
uicontrol(lqfig,'Style','text', ...
             'Position',[140 lower+85 60 15], ...
             'String','variable:', ...
             'Horizontal','right');

% selection of variable
lq_xvariable=uicontrol(lqfig,'Style','popup', ...
             'Position',[210 lower+80 180 25], ...
             'Background',buttoncolor, ...
             'String', [' absolute velocity | horizontal velocity |', ...
                        ' vertical velocity | pressure'], ... 
             'Value',2, ...
	     'CallBack', ['set(lq_xhold,''Value'',0)' ]);

% definition of cross section to be plotted
uicontrol(lqfig,'Style','frame', ...
             'Position',[0 lower 120 75]);
lq_xorient=uicontrol(lqfig,'Style','popup', ...
             'Position',[10 lower+44 95 25], ...
             'Background',buttoncolor, ...
             'String', [' horizontal | vertical '], ...
             'Value',2, ...
             'CallBack', [...
                 'if (get(lq_xorient,''Value'')==1),' ...
                   'set(lq_xplanetxt,''String'',''j-plane:''),' ...
                   'set(lq_xplot,''String'',''X-plot''),' ...
                   'set(lq_xhold,''Value'',0),' ...
                 'else,' ...
                   'set(lq_xplanetxt,''String'',''i-plane:''),' ...
                   'set(lq_xplot,''String'',''Y-plot''),' ...
                   'set(lq_xhold,''Value'',0),' ...
                 'end,' ]);
lq_xplanetxt=uicontrol(lqfig,'Style','text', ...
             'Position',[15 lower+15 55 15], ...
             'String','i-plane:', ...
             'Horizontal','left');
lq_xplane=uicontrol(lqfig,'Style','edit', ...
             'Position',[75 lower+12 30 21], ...
             'String','2', ...
             'Background',editcolor, ...
             'Horizontal','left');


% manual control of variable axis range
uicontrol(lqfig,'Style','frame', ...
	     'Position',[120 lower 150 75]);
lq_xmode=uicontrol(lqfig,'Style','checkbox', ...
             'Position',[140 lower+44 105 25], ...
             'Background',buttoncolor, ...
             'String', ['axis manual'], 'Value',0, ...
             'CallBack', [...
                 'if (get(lq_xmode,''Value'') == 1),' ...
                   'set(lq_xmintxt,''Visible'',''on''),' ...
                   'set(lq_xmin,''Visible'',''on''),' ...
                   'set(lq_xmaxtxt,''Visible'',''on''),' ...
                   'set(lq_xmax,''Visible'',''on''),' ...
                 'else,' ...
                   'set(lq_xmintxt,''Visible'',''off''),' ...
                   'set(lq_xmin,''Visible'',''off''),' ...
                   'set(lq_xmaxtxt,''Visible'',''off''),' ...
                   'set(lq_xmax,''Visible'',''off''),' ...
                 'end' ]);
lq_xmintxt=uicontrol(lqfig,'Style','text', ...
             'Position',[125 lower+15 30 15], ...
             'String','min:', ...
             'Visible','off', ...
             'Horizontal','left');
lq_xmin=uicontrol(lqfig,'Style','edit', ...
             'String','0', ...
             'Position',[157,lower+12,30,21], ...
             'Visible','off', ...
             'Background',editcolor, ...
             'Horizontal','left');
lq_xmaxtxt=uicontrol(lqfig,'Style','text', ...
             'Position',[200 lower+15 30 15], ...
             'String','max:', ...
             'Visible','off', ...
             'Horizontal','left');
lq_xmax=uicontrol(lqfig,'Style','edit', ...
             'String','1', ...
             'Position',[232,lower+12,30,21], ...
             'Visible','off', ...
             'Background',editcolor, ...
             'Horizontal','left');

% hold previous plot
lq_xhold=uicontrol(lqfig,'Style','checkbox', ...
             'Position',[290 lower+45 100 25], ...
             'Background',buttoncolor, ...
             'String', ['hold'], 'Value',0, ...
             'CallBack', [...
                 'if (get(lq_xhold,''Value'') == 0),' ...
                   'figure(plotfg), hold off,' ...
                 'else,' ...
                   'figure(plotfg), hold on,' ...
                 'end']);                       
tel=0;
tekst=[];
oudval=0;
	 
% make x-plot
xargs=['str2num(get(lq_sel,''String'')),' ...
       'get(lq_xvariable,''Value''),' ...
       'get(lq_xorient,''Value''),' ...
       'str2num(get(lq_xplane,''String''))'];
lq_xplot=uicontrol(lqfig,'Style','push', ...
             'Position',[290 lower+10 100 25], ...
             'String','Y-plot', ...
             'Background',buttoncolor, ...
             'CallBack',[' figure(plotfg), xplot(' xargs ');',setfigs]);

end;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% frame 3 (print)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
lower=sum(frameheight(6:9));

if (printframe),

uicontrol(lqfig,'Style','frame', ...
	     'Position',[0 lower+45 400 8], ...
             'Background', bordercolor );
uicontrol(lqfig,'Style','frame', ...
	     'Position',[0 lower 400 45]);
uicontrol(lqfig,'Style','text', ...
             'Position',[15 lower+15 150 15], ...
             'Horizontal','left', ... 
             'String','PRINT');

lq_format=uicontrol(lqfig,'Style','popup', ...
             'Position',[70 lower+10 75 25], ...
             'Background',buttoncolor, ...
             'String',' *.epsc | *.jpg ', ...
             'Visible','on', ...
             'Value', 1 );

uicontrol(lqfig,'Style','text', ...
             'Position',[65 lower+15 80 15], ...
             'Horizontal','right', ... 
             'Visible','off', ...
             'String','*.epsc file:');
lq_prt=uicontrol(lqfig,'Style','edit', ...
             'Position',[155 lower+12 100 21], ...
	     'Background',editcolor, ...
	     'Horizontal','left', ...
             'String','printfile');

% print orientation
uicontrol(lqfig,'Style','text', ...
             'Position',[15 lower+15 100 15], ... 
             'Visible','off', ...
             'String','orientation', ...
	     'Horizontal','left');
lq_orient=uicontrol(lqfig,'Style','popup', ...
             'Position',[100 lower+10 130 25], ...
	     'Background',buttoncolor, ...
             'Visible','off', ...
             'String',' portrait | landscape ', ...
             'Value', 1 );

% printfile
args=['get(lq_orient,''Value''),get(lq_format,''Value'')'];
uicontrol(lqfig,'Style','push', ...
             'Position',[290 lower+10 100 25], ...
             'String','print',   ...
	     'Background',buttoncolor, ...
             'CallBack',['figure(plotfg), liqprint(' args ')']);

end;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% frame 4 (movie)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
lower=sum(frameheight(7:9));

if (movieframe),
  
uicontrol(lqfig,'Style','frame', ...
	     'Position',[0 lower+80 400 8], ...
             'Background', bordercolor );
uicontrol(lqfig,'Style','frame', ...
	     'Position',[0 lower 400 80]);
uicontrol(lqfig,'Style','text', ...
             'Position',[15 lower+50 100 15], ... 
             'String','MOVIE', ...
	     'Horizontal','left');

lq_anim=uicontrol(lqfig,'Style','popup', ...
             'Position',[120 lower+46 110 23], ... 
             'String',['do not store | *.mat file ', ...
		 '| *.mpg file | *.avi file | *.jpg files'], ...
	     'Background',buttoncolor, ...
             'Value', 1 , ...
             'Visible','off' , ...
	     'CallBack', [...
                 'if (get(lq_anim,''Value'')==1),' ...
                   'set(lq_mpg,''Visible'',''off''),' ...
                   'set(lq_mpgtxt,''Visible'',''off''),' ...
                 'elseif (get(lq_anim,''Value'')==2),' ...
                   'set(lq_mpg,''Visible'',''on''),' ...
                   'set(lq_mpg,''String'',''matfile''),' ...
                   'set(lq_mpgtxt,''Visible'',''on''),' ...
                 'elseif (get(lq_anim,''Value'')==3),' ...
                   'set(lq_mpg,''Visible'',''on''),' ...
                   'set(lq_mpg,''String'',''mpgfile''),' ...
                   'set(lq_mpgtxt,''Visible'',''on''),' ...
                 'elseif (get(lq_anim,''Value'')==4),' ...
                   'set(lq_mpg,''Visible'',''on''),' ...
                   'set(lq_mpg,''String'',''avifile''),' ...
                   'set(lq_mpgtxt,''Visible'',''on''),' ...
                 'else,' ... 
                   'set(lq_mpg,''Visible'',''on''),' ...
                   'set(lq_mpg,''String'',''uvpf''),' ...
                   'set(lq_mpgtxt,''Visible'',''on''),' ...
                 'end'] );

lq_mpgtxt=uicontrol(lqfig,'Style','text', ...
             'Position',[250 lower+50 30 15], ...
             'Horizontal','right', ... 
             'String','file:', ...
             'Visible','off');

lq_mpg=uicontrol(lqfig,'Style','edit', ...
	     'String','filenaam', ...
	     'Position',[290, lower+47, 100, 21], ...
	     'Background',editcolor, ...
	     'Horizontal','left', ...
             'Visible','off');

% select first frame
uicontrol(lqfig,'Style','text', ...
             'Position',[10 lower+15 50 15], ... 
             'String',['from #:'], ...
             'Horizontal','right');
lq_from=uicontrol(lqfig,'Style','edit', ...
             'Position',[70 lower+12 50 21], ...
             'Horizontal','left', ...
             'Background',editcolor, ...
	     'String','1');

% select last frame
uicontrol(lqfig,'Style','text', ...
             'Position',[120 lower+15 50 15], ... 
             'String',['to #:'], ...
             'HorizontalAlignment','right');
lq_to=uicontrol(lqfig,'Style','edit', ...
             'Position',[180 lower+12 50 21], ...
             'Background',editcolor, ...
	     'Horizontal','left', ...
             'String','??');

% play
args=['str2num(get(lq_from,''String'')),' ...
      'str2num(get(lq_to,''String'')),' ...
      'get(lq_col,''Value'')+1,' ... 
      'get(lq_anim,''Value'')+0'];
uicontrol(lqfig,'Style','push', ...
             'Position',[290 lower+9 100 25], ... 
             'String','play', ...
             'Value',0, ...
	     'Background',buttoncolor, ...
	     'CallBack',[' figure(plotfg), liqdplot(' args ');',setfigs]);

end;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%frame 5 (close button)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
lower=sum(frameheight(8:9));

if (closeframe),

uicontrol(lqfig,'Style','frame', ...
	     'Position',[0 lower+35 400 8], ...
             'Background', bordercolor );

% create close button
lq_close=uicontrol(lqfig,'Style','push', ...
             'Position',[0 lower 400 35], ...
             'String','CLOSE CONTROL PANEL', ...
	     'Background',[0.50 0.0 0.0], ...
	     'Foreground',[1 1 1], ...
             'CallBack', 'close(lqfig)' );

% text that can be displayed instead of close button
lq_close_probetxt=uicontrol(lqfig,'Style','text', ...
             'Position',[0 lower+7 400 20], ...
             'Visible', 'Off', ...
	     'Background', 'w', ...
	     'Horizontal','center', ...
             'String', 'Click somewhere in the graphic window ...');
lq_close_livetxt=uicontrol(lqfig,'Style','text', ...
             'Position',[0 lower+7 400 20], ...
             'Visible', 'Off', ...
	     'Background', 'w', ...
	     'Horizontal','center', ...
             'String', 'In live mode. Wait or click STOP to interrupt ...');

% if button frame is last, then add a black frame
  if (sum(frameheight(8:9))==8),
  uicontrol(lqfig,'Style','frame', ...
               'Position', [0 lower-8 400 9], ...
               'Background', bordercolor );
  end;
end;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%frame 6 (part.paths, geometry, Psi/Om)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
lower=sum(frameheight(9:9));

if (partgeopsiomeframe),

% streamlines
uicontrol(lqfig,'Style','frame', ...
	     'Position', [0 lower 400 frameheight(8)], ...
             'Background', bordercolor );

uicontrol(lqfig,'Style','frame','Position',[0 lower+53 230 70]);
lq_strtxt=uicontrol(lqfig,'Style','text', ...
             'Position',[15 lower+68 200 15], ...
	     'Horizontal','left', ...
             'String',['control thru command window']);
lq_strm=uicontrol(lqfig,'Style','text', ...
             'Position',[15 lower+67 200 17], ...
             'Background',errorcolor, ...
             'Horizontal','left', ...
             'Visible','Off', ...
             'String',[' no particle paths available']);
uicontrol(lqfig,'Style','push', ...
             'Position',[15 lower+88 200 25], ... 
             'String','show particle paths', ...
             'Value',0, ...
	     'Background',buttoncolor, ...
	     'CallBack', [...
                 'strmfid=fopen(''stream.out'');' ...
                 'if strmfid~=-1, figure(plotfg), strmplot,' ...
                   'set(lq_strm,''Visible'',''Off''),' ...
                   'set(lq_strtxt,''Visible'',''On''),' ...
                 'else,' ...
                   'set(lq_strm,''Visible'',''On''),' ...
                   'set(lq_strtxt,''Visible'',''Off''),' ...
                 'end' ]);

% geometry
uicontrol(lqfig,'Style','frame', ...
	     'Position',[0 lower 230 45]);
uicontrol(lqfig,'Style','push', ...
             'Position',[15 lower+10 200 25], ... 
             'String','show geometry', ...
             'Value',0, ...
	     'Background',buttoncolor, ...
	     'CallBack',['figure(plotfg), clf, geoplot(1),', setfigs]);

% streamfunction-vorticity (psi-omega)
uicontrol(lqfig,'Style','frame', ...
	     'Position',[238 lower 162 123]);
lq_psomtxt=uicontrol(lqfig,'Style','text', ...
             'Position',[280 lower+90 100 15], ...
             'String',['PSI-OMEGA'], ...
             'Horizontal','left');
lq_psom=uicontrol(lqfig,'Style','popup', ...
             'Position',[250 lower+50 140 25], ...
             'Background',buttoncolor, ...
             'String', 'streamfunction | vorticity', ...
             'CallBack', [ 'set(lq_cmode,''Enable'',''on'')' ]);
lq_psomno=uicontrol(lqfig,'Style','text', ...
             'Position',[250 lower+90 130 17], ...
             'String','no psi-omega data', ...
             'Background',errorcolor, ...
             'Visible','off');

% plot psi-omega
psomargs=['get(lq_psom,''Value'')'];
lq_psomplot=uicontrol(lqfig,'Style','push', ...
             'Position',[250 lower+10 140 25], ...
             'String','plot psi/omega', ...
             'Value',0, ...
             'Background',buttoncolor, ...
             'CallBack', [...
                 'psomfid=fopen(''psiomega.dat'');' ...
                 'if psomfid==-1,' ...
                   'set(lq_psomno,''Visible'',''on''),' ...
                 'else,' ...
                   'fclose(psomfid);' ...
                   'set(lq_psomno,''Visible'',''off''),' ...
                   'figure(plotfg), psiomega(' psomargs '),' ...
		   'eval(setfigs),' ...
                 'end']);

end;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% frame 7 (directory)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
lower=0;

if (directoryframe),

uicontrol(lqfig,'Style','frame', ...
             'Position', [0 lower+32 400 8], ...
             'Background', bordercolor);

uicontrol(lqfig,'Style','frame', ...
             'Position',[0 lower 400 32]);
uicontrol(lqfig,'Style','text', ...
             'Position',[15 lower+8 100 15], ... 
             'HorizontalAlignment','left', ...
             'String',['directory:'] )
lq_dir=uicontrol(lqfig,'Style','edit', ...
             'Position',[80 lower+5 310 21], ...
             'Background', editcolor, ...
	     'Horizontal','left', ...
             'String',pwd, ...
	     'CallBack', [...
		 'cd(get(lq_dir, ''String''));', ...
		 'set(lq_many, ''String'', ''??'')' ] );

end;

